django-online
=============

.. image:: https://secure.travis-ci.org/thoas/django-online.png?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/thoas/django-online

Standalone Django application to know if a django user is online or not.
